
pycontrails
===========

*Python library for modeling contrails and other aviation climate impacts.*

Learn more on `contrails.org <https://contrails.org>`_.

.. list-table::
   :widths: 30 70
   :header-rows: 0

   * - **Version**
     - |PyPI version| |Supported python versions|
   * - **Citation**
     - |DOI|
   * - **Tests**
     - |Unit test| |Docs| |Release|
   * - **License**
     - |Apache License 2.0|
   * - **Community**
     - |Github Discussions| |Github Issues| |Github PRs|

.. toctree::
   :titlesonly:
   :maxdepth: 1
   :caption: Getting Started

   install
   develop
   examples
   tutorials

.. toctree::
   :titlesonly:
   :maxdepth: 1
   :caption: Resources

   api
   literature
   contributing
   changelog

.. toctree::
   :titlesonly:
   :maxdepth: 1
   :caption: Links

   Github <https://github.com/contrailcirrus/pycontrails>
   Contrails.org <https://contrails.org>
   Contrails API <https://api.contrails.org>
   Contrails Map <https://map.contrails.org>
   Contrails Navigator <https://forecast.contrails.org>


.. |PyPI version| image:: https://img.shields.io/pypi/v/pycontrails.svg
   :alt: PyPI version
   :target: https://pypi.python.org/pypi/pycontrails

.. |Supported python versions| image:: https://img.shields.io/pypi/pyversions/pycontrails.svg
   :alt: Supported python versions
   :target: https://pypi.python.org/pypi/pycontrails

.. |DOI| image:: https://zenodo.org/badge/617248930.svg
   :alt: DOI
   :target: https://zenodo.org/badge/latestdoi/617248930

.. |Unit test| image:: https://github.com/contrailcirrus/pycontrails/actions/workflows/test.yaml/badge.svg
   :alt: Unit test
   :target: https://github.com/contrailcirrus/pycontrails/actions/workflows/test.yaml

.. |Docs| image:: https://github.com/contrailcirrus/pycontrails/actions/workflows/docs.yaml/badge.svg
   :alt: Docs
   :target: https://github.com/contrailcirrus/pycontrails/actions/workflows/docs.yaml

.. |Release| image:: https://github.com/contrailcirrus/pycontrails/actions/workflows/release.yaml/badge.svg
   :alt: Release
   :target: https://github.com/contrailcirrus/pycontrails/actions/workflows/release.yaml

.. |Apache License 2.0| image:: https://img.shields.io/pypi/l/pycontrails.svg
   :alt: Apache License 2.0
   :target: https://github.com/contrailcirrus/pycontrails/blob/main/LICENSE

.. |Github Discussions| image:: https://img.shields.io/github/discussions/contrailcirrus/pycontrails
   :alt: Github Discussions
   :target: https://github.com/contrailcirrus/pycontrails/discussions

.. |Github Issues| image:: https://img.shields.io/github/issues/contrailcirrus/pycontrails
   :alt: Github Issues
   :target: https://github.com/contrailcirrus/pycontrails/issues

.. |Github PRs| image:: https://img.shields.io/github/issues-pr/contrailcirrus/pycontrails
   :alt: Github PRs
   :target: https://github.com/contrailcirrus/pycontrails/pulls
